@@ -153,7 +153,8 @@ get '/ajax/content/report/ipinventory' => require_login sub {
     return unless scalar @results;
 
     if ( request->is_ajax ) {
-        template 'ajax/report/ipinventory.tt', { results => \@results, },
+        my $json = to_json( \@results );
+        template 'ajax/report/ipinventory.tt', { results => $json },
             { layout => undef };
     }
     else {
